@@ -80,8 +80,11 @@ LinHtmlDisplayForm::~LinHtmlDisplayForm()
 
 
 void LinHtmlDisplayForm::displayText(
+  QString feedName,
   QString textUrl)
 {
+  setWindowTitle(feedName);
+
   sourceUrl = textUrl;
   reply = qnam->get(QNetworkRequest(QUrl(sourceUrl)));
 
