@@ -76,7 +76,7 @@ public:
 
 public slots:
   void setProgram(
-    QString title,
+    QString feedName,
     QString mediaUrl);
 
   void pausePlaying();
